==> gis-viewer-3.7.0-20150711.010524-8-servicearchive.tar.gz: org/gcube/portlets/user/gisviewer/client/GisViewerParameters.java <==
package org.gcube.portlets.user.gisviewer.client;

import java.util.Arrays;
import java.util.List;


public class GisViewerParameters {	

	private String projection = null;
	private String openingGroup = null;
	private List<String> openingLayers = null;
	private GisViewerSaveHandler gisViewerSaveHandler = null;
	private DataPanelOpenListener dataPanelOpenHandler = null;
	private boolean openDataPanelAtStart = Constants.geoWindowDataPanelOpenedAtStart;
	
	//protected static GisViewerParameters instance = new GisViewerParameters();
//	public static GisViewerParameters getInstance() {
//		return instance;
//	}
	
	public GisViewerParameters(){		
	}
	
	
	
	/**
	 * @param projection
	 * @param groupName
	 * @param layers
	 * @param gisViewerSaveHandler
	 */
	public GisViewerParameters(String projection, String openingGroup, List<String> openingLayers, GisViewerSaveHandler gisViewerSaveHandler) {
		this.projection = projection;
		this.openingGroup = openingGroup;
		this.openingLayers = openingLayers;
		this.gisViewerSaveHandler = gisViewerSaveHandler;
	}

	public void setProjection(String projection) {
		this.projection = projection;
	}

	public void setOpeningGroup(String groupName) {
		this.openingGroup = groupName;
	}

	public void setOpeningLayers(List<String> layers) {
		this.openingLayers = layers;
	}

	public void setOpeningLayers(String[] layers) {
		this.openingLayers = Arrays.asList(layers);
	}


	public String getProjection() {
		return projection;
	}
	
	public String getOpeningGroup() {
		return this.openingGroup;
	}

	public List<String> getOpeningLayers() {
		return this.openingLayers;
	}
	
	public void setGisViewerSaveHandler(GisViewerSaveHandler gisViewerSaveHandler) {
		this.gisViewerSaveHandler = gisViewerSaveHandler;
	}
	
	public GisViewerSaveHandler getGisViewerSaveHandler() {
		return gisViewerSaveHandler;
	}

	/**
	 * @return the openDataPanelAtStart
	 */
	public boolean isOpenDataPanelAtStart() {
		return openDataPanelAtStart;
	}

	/**
	 * @param openDataPanelAtStart the openDataPanelAtStart to set
	 */
	public void setOpenDataPanelAtStart(boolean openDataPanelAtStart) {
		this.openDataPanelAtStart = openDataPanelAtStart;
	}
	
	/**
	 * @param dataPanelOpenHandler the dataPanelOpenHandler to set
	 */
	public void setDataPanelOpenListener(DataPanelOpenListener dataPanelOpenHandler) {
		this.dataPanelOpenHandler = dataPanelOpenHandler;
	}
	
	/**
	 * @return the dataPanelOpenHandler
	 */
	public DataPanelOpenListener getDataPanelOpenHandler() {
		return dataPanelOpenHandler;
	}
}

==> gis-viewer-4.2.2-20190730.000741-417-servicearchive.tar.gz: org/gcube/portlets/user/gisviewer/client/GisViewerParameters.java <==
package org.gcube.portlets.user.gisviewer.client;


/**
 * The Class GisViewerParameters.
 *
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * Sep 26, 2016
 */
public class GisViewerParameters {

	private String projection = null;
	private GisViewerSaveHandler gisViewerSaveHandler = null;
	private DataPanelOpenListener dataPanelOpenHandler = null;
	private boolean openDataPanelAtStart = Constants.geoWindowDataPanelOpenedAtStart;

	/**
	 * Instantiates a new gis viewer parameters.
	 */
	public GisViewerParameters(){
	}

	/**
	 * Instantiates a new gis viewer parameters.
	 *
	 * @param projection the projection
	 * @param gisViewerSaveHandler the gis viewer save handler
	 */
	public GisViewerParameters(String projection, GisViewerSaveHandler gisViewerSaveHandler) {
		this.projection = projection;
		this.gisViewerSaveHandler = gisViewerSaveHandler;
	}

	/**
	 * Sets the projection.
	 *
	 * @param projection the new projection
	 */
	public void setProjection(String projection) {
		this.projection = projection;
	}

	/**
	 * Gets the projection.
	 *
	 * @return the projection
	 */
	public String getProjection() {
		return projection;
	}

	/**
	 * Sets the gis viewer save handler.
	 *
	 * @param gisViewerSaveHandler the new gis viewer save handler
	 */
	public void setGisViewerSaveHandler(GisViewerSaveHandler gisViewerSaveHandler) {
		this.gisViewerSaveHandler = gisViewerSaveHandler;
	}

	/**
	 * Gets the gis viewer save handler.
	 *
	 * @return the gis viewer save handler
	 */
	public GisViewerSaveHandler getGisViewerSaveHandler() {
		return gisViewerSaveHandler;
	}

	/**
	 * Checks if is open data panel at start.
	 *
	 * @return the openDataPanelAtStart
	 */
	public boolean isOpenDataPanelAtStart() {
		return openDataPanelAtStart;
	}

	/**
	 * Sets the open data panel at start.
	 *
	 * @param openDataPanelAtStart the openDataPanelAtStart to set
	 */
	public void setOpenDataPanelAtStart(boolean openDataPanelAtStart) {
		this.openDataPanelAtStart = openDataPanelAtStart;
	}

	/**
	 * Sets the data panel open listener.
	 *
	 * @param dataPanelOpenHandler the dataPanelOpenHandler to set
	 */
	public void setDataPanelOpenListener(DataPanelOpenListener dataPanelOpenHandler) {
		this.dataPanelOpenHandler = dataPanelOpenHandler;
	}

	/**
	 * Gets the data panel open handler.
	 *
	 * @return the dataPanelOpenHandler
	 */
	public DataPanelOpenListener getDataPanelOpenHandler() {
		return dataPanelOpenHandler;
	}
}
